;; Generated package description from dts-mode.el  -*- no-byte-compile: t -*-
(define-package "dts-mode" "0.1.0.0.20201127.222749" "Major mode for Device Tree source files" 'nil :url "https://elpa.gnu.org/packages/dts-mode.html" :keywords '("languages") :authors '(("Ben Gamari" . "ben@smart-cactus.org")) :maintainer '("Ben Gamari" . "ben@smart-cactus.org"))
